@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2010 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2011 Live Networks, Inc.  All rights reserved.
 // A source object for AAC audio files in ADTS format
 // Implementation
 
@@ -72,7 +72,7 @@ ADTSAudioFileSource::createNew(UsageEnvironment& env, char const* fileName) {
 #ifndef _WIN32_WCE
     rewind(fid);
 #else
-    fseek(fid, SEEK_SET,0);
+    SeekFile64(fid, SEEK_SET,0);
 #endif
 #ifdef DEBUG
     fprintf(stderr, "Read first frame: profile %d, "
@@ -138,7 +138,7 @@ void ADTSAudioFileSource::doGetNextFrame() {
 
   // If there's a 'crc_check' field, skip it:
   if (!protection_absent) {
-    fseek(fFid, 2, SEEK_CUR);
+    SeekFile64(fFid, 2, SEEK_CUR);
     numBytesToRead = numBytesToRead > 2 ? numBytesToRead - 2 : 0;
   }
 
