@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2010 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2011 Live Networks, Inc.  All rights reserved.
 // A generic SIP client
 // Implementation
 
@@ -168,7 +168,6 @@ static char* getLine(char* startOfLine) {
 
 char* SIPClient::invite(char const* url, Authenticator* authenticator) {
   // First, check whether "url" contains a username:password to be used:
-  fInviteStatusCode = 0;
   char* username; char* password;
   if (authenticator == NULL
       && parseSIPURLUsernamePassword(url, username, password)) {
@@ -251,7 +250,7 @@ char* SIPClient::invite1(Authenticator* authenticator) {
       "Content-Type: application/sdp\r\n"
       "%s" /* Proxy-Authorization: line (if any) */
       "%s" /* User-Agent: line */
-      "Content-length: %d\r\n\r\n"
+      "Content-Length: %d\r\n\r\n"
       "%s";
     unsigned inviteCmdSize = strlen(cmdFmt)
       + fURLSize
@@ -314,7 +313,6 @@ char* SIPClient::invite1(Authenticator* authenticator) {
     }
   } while (0);
 
-  fInviteStatusCode = 2;
   return NULL;
 }
 
@@ -530,9 +528,9 @@ unsigned SIPClient::getResponseCode() {
       delete[] toTagStr;
 
       if (sscanf(lineStart, "Content-Length: %d", &contentLength) == 1
-          || sscanf(lineStart, "Content-length: %d", &contentLength) == 1) {
+          || sscanf(lineStart, "Content-Length: %d", &contentLength) == 1) {
         if (contentLength < 0) {
-          envir().setResultMsg("Bad \"Content-length:\" header: \"",
+          envir().setResultMsg("Bad \"Content-Length:\" header: \"",
                                lineStart, "\"");
           break;
         }
@@ -546,11 +544,11 @@ unsigned SIPClient::getResponseCode() {
     }
 
     // Use the remaining data as the SDP descr, but first, check
-    // the "Content-length:" header (if any) that we saw.  We may need to
+    // the "Content-Length:" header (if any) that we saw.  We may need to
     // read more data, or we may have extraneous data in the buffer.
     char* bodyStart = nextLineStart;
     if (bodyStart != NULL && contentLength >= 0) {
-      // We saw a "Content-length:" header
+      // We saw a "Content-Length:" header
       unsigned numBodyBytes = &readBuf[bytesRead] - bodyStart;
       if (contentLength > (int)numBodyBytes) {
         // We need to read more data.  First, make sure we have enough
@@ -562,7 +560,7 @@ unsigned SIPClient::getResponseCode() {
           = readBufSize - (bytesRead + (readBuf - readBuffer));
         if (numExtraBytesNeeded > remainingBufferSize) {
           char tmpBuf[200];
-          sprintf(tmpBuf, "Read buffer size (%d) is too small for \"Content-length:\" %d (need a buffer size of >= %d bytes\n",
+          sprintf(tmpBuf, "Read buffer size (%d) is too small for \"Content-Length:\" %d (need a buffer size of >= %d bytes\n",
                   readBufSize, contentLength,
                   readBufSize + numExtraBytesNeeded - remainingBufferSize);
           envir().setResultMsg(tmpBuf);
@@ -608,8 +606,7 @@ char* SIPClient::inviteWithPassword(char const* url, char const* username,
   delete[] (char*)fUserName; fUserName = strDup(username);
   fUserNameSize = strlen(fUserName);
 
-  Authenticator authenticator;
-  authenticator.setUsernameAndPassword(username, password);
+  Authenticator authenticator(username, password);
   char* inviteResult = invite(url, &authenticator);
   if (inviteResult != NULL) {
     // We are already authorized
@@ -642,7 +639,7 @@ Boolean SIPClient::sendACK() {
       "To: %s;tag=%s\r\n"
       "Call-ID: %u@%s\r\n"
       "CSeq: %d ACK\r\n"
-      "Content-length: 0\r\n\r\n";
+      "Content-Length: 0\r\n\r\n";
     unsigned cmdSize = strlen(cmdFmt)
       + fURLSize
       + 2*fUserNameSize + fOurAddressStrSize + 20 /* max int len */
@@ -683,7 +680,7 @@ Boolean SIPClient::sendBYE() {
       "To: %s;tag=%s\r\n"
       "Call-ID: %u@%s\r\n"
       "CSeq: %d ACK\r\n"
-      "Content-length: 0\r\n\r\n";
+      "Content-Length: 0\r\n\r\n";
     unsigned cmdSize = strlen(cmdFmt)
       + fURLSize
       + 2*fUserNameSize + fOurAddressStrSize + 20 /* max int len */
@@ -731,7 +728,6 @@ Boolean SIPClient::processURL(char const* url) {
     return True;
   } while (0);
 
-  fInviteStatusCode = 1;
   return False;
 }
 
